@@ -10,30 +10,30 @@
 //
 //
 
-#include <assert.h>
-
 #include "generatormap.h"
-#include "textgen.h"
+#include "textgenerator.h"
 #include "mainoutputbuffer.h"
 
 using namespace std;
 
 GeneratorMap::GeneratorMap() :
-  default_generator (0)
+  default_generator (new TextGenerator)
 {
 }
 
 GeneratorMap::~GeneratorMap()
 {
+  for (MapType::const_iterator it = generatormap.begin(); it != generatormap.end(); ++it)
+    delete it->second;
   delete default_generator;
 }
 
 void
 GeneratorMap::setDefaultGenerator(TextGenerator *gen)
 {
-  assert (! default_generator);
-
-  default_generator = gen;
+    if (default_generator)
+        delete default_generator;
+    default_generator = gen;
 }
 
 void
@@ -48,7 +48,9 @@ GeneratorMap::getGenerator(const string &elem)
   MapType::const_iterator it = generatormap.find(elem);
   if (it == generatormap.end())
     {
-      TextGenerator *missing = missingGenerator(elem);
+      // create a copy of the prototype and substitute the style.  
+      TextGenerator *missing = new TextGenerator(*default_generator);
+      missing->subst_style(elem);
 
       generatormap[elem] = missing;
       return missing;
@@ -57,29 +59,14 @@ GeneratorMap::getGenerator(const string &elem)
   return it->second;
 }
 
-TextGenerator *
-GeneratorMap::missingGenerator(const string &elem)
-{
-  if (! default_generator)
-    default_generator = new TextGenerator;
-
-  return default_generator;
-}
-
-void
-GeneratorMap::generate( const std::string &elem, const std::string &s )
-{
-  outputbuffer->output(getGenerator(elem)->generate(s.c_str()));
-}
-
-void
-GeneratorMap::generateln( const std::string &elem, const std::string &s )
-{
-  outputbuffer->output_ln(getGenerator(elem)->generateln(s.c_str()));
-}
-
 void
 GeneratorMap::generateEntire( const std::string &elem, const std::string &s )
 {
   outputbuffer->output(getGenerator(elem)->generateEntire(s.c_str()));
 }
+
+void
+GeneratorMap::generateNL( const std::string &s )
+{
+  outputbuffer->output_ln(s);
+}
