@@ -15,6 +15,7 @@
 #include <outputgenerator.h>
 
 class TextGenerator;
+class TextStyle;
 
 /**
 a specialized output generator that also generates the line number before each line
@@ -25,11 +26,14 @@ class LineOutputGenerator : public OutputGenerator
 {
 private:
   bool generate_ref;
+  TextStyle *anchor;
+  std::string anchor_line_prefix;
   unsigned int line_num;
   TextGenerator *line_num_generator;
 
 public:
-    LineOutputGenerator(OutputBuffer& buff, std::ostream& os, bool genref);
+    LineOutputGenerator(OutputBuffer& buff, std::ostream& os,
+      TextStyle *anch, bool genref, const std::string &prefix);
 
     ~LineOutputGenerator();
 
