@@ -32,30 +32,35 @@
      BOLD = 258,
      ITALICS = 259,
      UNDERLINE = 260,
-     KEY = 261,
-     COLOR = 262
+     FIXED = 261,
+     NOTFIXED = 262,
+     KEY = 263,
+     COLOR = 264
    };
 #endif
 #define BOLD 258
 #define ITALICS 259
 #define UNDERLINE 260
-#define KEY 261
-#define COLOR 262
+#define FIXED 261
+#define NOTFIXED 262
+#define KEY 263
+#define COLOR 264
 
 
 
 
 #if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
-#line 49 "./optparser.yy"
+#line 50 "./optparser.yy"
 typedef union YYSTYPE {
   int tok ; /* command */
   const std::string * string ; /* string : id, ... */
-  int flag ;
+  TagStyle flag ;
   Tag *tag ;
   Tags *tags ;
+  TagStyles *tagstyles;
 } YYSTYPE;
 /* Line 1285 of yacc.c.  */
-#line 59 "optparser.h"
+#line 64 "optparser.h"
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
 # define YYSTYPE_IS_TRIVIAL 1
