@@ -1,7 +1,7 @@
 //
 // C++ Implementation: textformatter
 //
-// Description: 
+// Description:
 //
 //
 // Author: Lorenzo Bettini <bettini@gnu.org>, (C) 2004
@@ -15,21 +15,19 @@
 
 using namespace std;
 
-TextFormatter::TextFormatter(TextFormatter *f) :
+TextFormatter::TextFormatter(TextFormatterPtr f) :
   decorator(f)
 {
 }
 
 TextFormatter::~TextFormatter()
 {
-  if (decorator)
-    delete decorator;
 }
 
 void
-TextFormatter::setFormatter(TextFormatter *f)
+TextFormatter::setFormatter(TextFormatterPtr f)
 {
-  if (decorator)
+  if (decorator.get())
     decorator->setFormatter(f);
   else
     decorator = f;
@@ -40,19 +38,19 @@ TextFormatter::format(const string &elem, const string &text)
 {
   if (! text.size())
     return;
-  
+
   generatormap->generateEntire(elem, _preformat(text));
 }
 
 void
-TextFormatter::format_nl(const std::string &elem, const string &text)
+TextFormatter::format_nl(const string &text)
 {
   string preformat_text = _preformat(text);
-  
+
   if (preformat_text == text)
-    preformat_text = "";
-  
-  generatormap->generateln(elem, preformat_text);
+    preformat_text = "\n";
+
+  generatormap->generateNL(preformat_text);
 }
 
 const string
@@ -60,15 +58,15 @@ TextFormatter::_preformat(const string &text)
 {
   if (! text.size())
     return text;
-  
+
   string preformat_text = text;
   TextFormatter *inner = this;
   while (inner) // start the chain of preformatting
   {
     preformat_text = inner->preformat(preformat_text);
-    inner = inner->decorator;
+    inner = inner->decorator.get();
   }
-  
+
   return preformat_text;
 }
 
