@@ -17,6 +17,8 @@
 class TextFormatter;
 
 #include <string>
+#include <stack>
+#include <boost/shared_ptr.hpp>
 
 /**
 the class that actually performs regular expression processing
@@ -25,18 +27,28 @@ the class that actually performs regular expression processing
 */
 class RegExpEngine
 {
+  protected:
+    RegExpStatePtr currentstate, initial_state;
+
   private:
-    RegExpStatePtr currentstate;
     TextFormatter *formatter;
+    typedef std::stack<RegExpStatePtr> stack_of_states;
+    stack_of_states states_stack;
+
+  protected:
+    virtual void enterState(int index);
+    virtual void exitState();
+    virtual void exitAll();
+    virtual void format(int index, const std::string &s);
 
 public:
   RegExpEngine(RegExpStatePtr v, TextFormatter *pre) : currentstate(v), formatter(pre) {}
 
-  ~RegExpEngine();
+  virtual ~RegExpEngine();
 
   void process_file(const char *file);
 };
 
-int process_file(const char *file, TextFormatter *pre, const std::string &path, const std::string &lang_file);
+typedef boost::shared_ptr<RegExpEngine> RegExpEnginePtr;
 
 #endif
