@@ -345,9 +345,6 @@ StartApp::start(int argc, char * argv[])
   delete outputbuffer;
   outputbuffer = 0;
 
-  if (textstyles)
-    delete textstyles;
-
   if (tags)
     delete tags;
 
